/*** Event - study graph .do file ***

This file creates the event-study graph to appear in the paper.

Dependencies:  ssc install parmest

*****************************************/


* 1) Load dataset * 

clear
set more off
capture log close

use  ../../Data/Data_final.dta, replace

* Choose Palatino Fonts *
local graphfont "Palatino"
graph set eps fontface `graphfont'
graph set eps fontfaceserif `graphfont'
graph set eps  /*echo back preferences*/
 
graph set window fontface `graphfont'
graph set window fontfaceserif `graphfont'
graph set window /*echo back preferences*/


sort id year

* Create Necessary Dummies and Legislature variables *
egen dum_w_all_lag=rowmax(dum_w_int_lag dum_w_ext_lag dum_w_prop_lag)

* Drop 1994 as these transfers are determined in 1993 *
drop if year==1994 

* Keep only municipalities that had at least a change in their connection status *
egen suma=sum(dum_w_all_lag), by(id)
drop if suma==0 | suma==12
drop suma



* 2) Eliminate Time Effects *

/* Note: The regression is ran only for the group of municipalities that experience
at least some variation in their connection status (any connection) */

reg transfers_pc i.year `controls'
predict transfers_pc_res, res
replace transfers_pc_res=transfers_pc_res+_b[_cons]

* Keep only relevant variables *
keep transfers_pc_res transfers_pc dum_w_ext_lag dum_w_int_lag dum_w_prop_lag dum_w_all_lag town id year 
assert(dum_w_ext_lag!=. & dum_w_int_lag!=. & dum_w_prop_lag!=. & dum_w_all_lag!=.) 
tab year


* 3) Define the groups for the two graphs * 

* 3.1) No connection in legislature t, connection in legislature t+1 *

gen aux = (year == 1997 | year == 2002) & dum_w_ext_lag == 1 & l.dum_w_ext_lag == 0 & l2.dum_w_ext_lag == 0 /*
 */ & f.dum_w_ext_lag == 1 & f2.dum_w_ext_lag == 1
 
gen group_01 = 0
replace group_01 = 1 if year  ==1995 & f2.aux == 1
replace group_01 = 1 if year  ==1996 & f.aux == 1
replace group_01 = 1 if year  ==1997 & aux == 1
replace group_01 = 1 if year  ==1998 & l.aux == 1
replace group_01 = 1 if year  ==1999 & l2.aux == 1

replace group_01 = 1 if year  ==2000 & f2.aux == 1
replace group_01 = 1 if year  ==2001 & f.aux == 1
replace group_01 = 1 if year  ==2002 & aux == 1
replace group_01 = 1 if year  ==2003 & l.aux == 1
replace group_01 = 1 if year  ==2004 & l2.aux == 1
replace group_01 = 1 if year  ==2005 & l3.aux == 1

drop aux

* 3.2) Connection in legislature t, no connection in legislature t+1 *

gen aux = (year == 1997 | year == 2002) & dum_w_ext_lag == 0 & l.dum_w_ext_lag == 1 & l2.dum_w_ext_lag == 1 /*
 */ & f.dum_w_ext_lag == 0 & f2.dum_w_ext_lag == 0

gen group_10 = 0
replace group_10 = 1 if year  ==1995 & f2.aux == 1
replace group_10 = 1 if year  ==1996 & f.aux == 1
replace group_10 = 1 if year  ==1997 & aux == 1
replace group_10 = 1 if year  ==1998 & l.aux == 1
replace group_10 = 1 if year  ==1999 & l2.aux == 1

replace group_10 = 1 if year  ==2000 & f2.aux == 1
replace group_10 = 1 if year  ==2001 & f.aux == 1
replace group_10 = 1 if year  ==2002 & aux == 1
replace group_10 = 1 if year  ==2003 & l.aux == 1
replace group_10 = 1 if year  ==2004 & l2.aux == 1
replace group_10 = 1 if year  ==2005 & l3.aux == 1


* 3.3) No connection in legislature t, no connection in legislature t+1 *

drop aux

gen aux = (year == 1997 | year == 2002) & dum_w_ext_lag == 0 & l.dum_w_ext_lag == 0 & l2.dum_w_ext_lag == 0 /*
 */ & f.dum_w_ext_lag == 0 & f2.dum_w_ext_lag == 0  // Identify those that do not get nor lose a connection in 96 and 01 elections

gen group_00 = 0
replace group_00 = 1 if year  ==1995 & f2.aux == 1
replace group_00 = 1 if year  ==1996 & f.aux == 1
replace group_00 = 1 if year  ==1997 & aux == 1
replace group_00 = 1 if year  ==1998 & l.aux == 1
replace group_00 = 1 if year  ==1999 & l2.aux == 1

replace group_00 = 1 if year  ==2000 & f2.aux == 1
replace group_00 = 1 if year  ==2001 & f.aux == 1
replace group_00 = 1 if year  ==2002 & aux == 1
replace group_00 = 1 if year  ==2003 & l.aux == 1
replace group_00 = 1 if year  ==2004 & l2.aux == 1
replace group_00 = 1 if year  ==2005 & l3.aux == 1



* 3.5) Defining Year Groups * 
gen years_minus2  = (year == 1995|year == 2000) 
gen years_minus1  = (year == 1996|year == 2001) 
gen years_0  = (year == 1997|year == 2002) 
gen years_1  = (year == 1998|year == 2003)
gen years_2  = (year == 2004 | year==1999)
gen years_3 = (year==2005)


* 4) Regressions *

** Panel I - Effect of gaining a connection ** 
reg transfers_pc_res years_minus2 years_minus1 years_0 years_1 years_2 years_3  if group_01==1,  nocons

tempfile timedum_01
parmest, saving(`timedum_01')

** Panel II -  Effect of losing a connection ** 
reg transfers_pc_res years_minus2 years_minus1 years_0 years_1 years_2 years_3  if group_10==1,  nocons
tempfile timedum_10
parmest, saving(`timedum_10')

** Panel III - Effect of never gaining a connection ** 
reg transfers_pc_res years_minus2 years_minus1 years_0 years_1 years_2 years_3  if group_00==1,  nocons
tempfile timedum_00
parmest, saving(`timedum_00')


* 5) Draw Graphs *

* 5.1) Generate useful variables and store means at both sides of the cutoff 

gen year_pre  = (years_minus2 == 1 | years_minus1 == 1)
gen year_post = (years_0 == 1 | years_1 == 1 | years_2 == 1  | years_3 == 1)

summ transfers_pc_res if (group_01==1 & year_pre == 1)
scalar transfers_pc_01_left = r(mean)

summ transfers_pc_res if (group_01==1 & year_post == 1)
scalar transfers_pc_01_right = r(mean)

summ transfers_pc_res if (group_10==1 & year_pre == 1)
scalar transfers_pc_10_left = r(mean)

summ transfers_pc_res if (group_10==1 & year_post == 1)
scalar transfers_pc_10_right = r(mean)

summ transfers_pc_res if (group_00==1 & year_pre == 1)
scalar transfers_pc_00_left = r(mean)

summ transfers_pc_res if (group_00==1 & year_post == 1)
scalar transfers_pc_00_right = r(mean)


*** 0 -> 1 Graph ***

clear
use `timedum_01'

gen year=-2 if parm=="years_minus2"
replace year=-1 if parm=="years_minus1"
replace year=0 if parm=="years_0"
replace year=1 if parm=="years_1"
replace year=2 if parm=="years_2"
replace year=3 if parm=="years_3"

gen  transfers_pc_01_left = transfers_pc_01_left  // Calculate means before and after the connection
gen  transfers_pc_01_right = transfers_pc_01_right

set scheme sol
 twoway     (scatter estimate year) || /*
	   */  (line transfers_pc_01_left year if year<0, lpattern(dash) lcolor(gs8))  /*
	   */  (line transfers_pc_01_right year if year>=0 , lpattern(dash) lcolor(gs8) /*
	   */  legend(off) xline(-0.5) graphr(color(gs16) margin(zero)) title("Gaining a connection", size(large)) /*
	   */  xtitle(Years)  ytitle(Transfers p.c.) name(Graph_01, replace) aspect(1, placement(center)) nodraw ylab(205(5)220))
	  
		
*** 1 -> 0 Graph ***

use `timedum_10', replace

gen year=-2 if parm=="years_minus2"
replace year=-1 if parm=="years_minus1"
replace year=0 if parm=="years_0"
replace year=1 if parm=="years_1"
replace year=2 if parm=="years_2"
replace year=3 if parm=="years_3"

gen  transfers_pc_10_left = transfers_pc_10_left  
gen  transfers_pc_10_right = transfers_pc_10_right

set scheme sol
qui: twoway     (scatter estimate year) || /*
	   */  (line transfers_pc_10_left year if year<0, lpattern(dash) lcolor(gs8))  /*
	   */  (line transfers_pc_10_right year if year>=0 , lpattern(dash) lcolor(gs8) /*
	   */  legend(off) xline(-0.5) graphr(color(gs16) margin(zero)) title("Losing a connection", size(large)) /*
	   */  xtitle(Years)  ytitle(Transfers p.c.) name(Graph_10, replace) aspect(1, placement(center)) nodraw ylab(205(5)220))
	  
	  
*** 0 -> 0 Graph ***

use `timedum_00', replace

gen year=-2 if parm=="years_minus2"
replace year=-1 if parm=="years_minus1"
replace year=0 if parm=="years_0"
replace year=1 if parm=="years_1"
replace year=2 if parm=="years_2"
replace year=3 if parm=="years_3"

gen  transfers_pc_00_left = transfers_pc_00_left  
gen  transfers_pc_00_right = transfers_pc_00_right

set scheme sol
twoway     (scatter estimate year) || /*
	   */  (line transfers_pc_00_left year if year<0, lpattern(dash) lcolor(gs8))  /*
	   */  (line transfers_pc_00_right year if year>=0 , lpattern(dash) lcolor(gs8) /*
	   */  legend(off) xline(-0.5) graphr(color(gs16) margin(zero)) title("Never connected", size(large)) /*
	   */  xtitle(Years)  ytitle(Transfers p.c.) name(Graph_00, replace) aspect(1, placement(center)) nodraw ylab(205(5)220))
	   
	  
graph combine Graph_01 Graph_10 Graph_00, rows(1) graphr(color(gs16))  ycommon name(combined, replace)
graph display combined, margins(zero) ysize(2) scale(2)

graph export ..\..\Figures\Event_study.eps, replace
graph export ..\..\Figures\Event_study.png, replace
