
/******* Estimation ************

This .do file generates the tables for the paper Sending the Pork Home. 

* Structure * 

* (Table 2) Baseline estimation 
* (Table 3) Spending cycle 
* (Table 4) Localness (Marangoni/Tronconi dataset)
* (Table 5) District-level analysis
* (Table 6) Mechanisms
* (Table 7) Placebos and robustness

Note: requires esttab

*********************************/

* Initialize*

clear all
set more off
set matsize 11000

use  ../../Data/Data_final.dta, replace

local controls "win_lag density_lag surface pop_lag military capp l1.pop2 l1.pop3 l1.pop_1 l1.pop_2 l1.pop_3 l1.pop_4 l1.pop_5 l1.pop_6 l1.pop_7 l1.pop_8 l1.pop_9 l1.pop_10 l1.pop_11 l1.pop_12 "  
local controls_panel "win_lag  density_lag pop_lag l1.pop2 l1.pop3 l1.pop_1 l1.pop_2 l1.pop_3 l1.pop_4 l1.pop_5 l1.pop_6 l1.pop_7 l1.pop_8 l1.pop_9 l1.pop_10 l1.pop_11 l1.pop_12 "


* (Table 2) Baseline estimation *

eststo clear
local x "dum_w_ext_lag dum_w_int_lag dum_w_prop_lag"   			

*OLS*
eststo: qui: xi: reg transfers_pc `x' `controls' i.year i.region, cluster (id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "N" , replace
test dum_w_ext_lag=dum_w_int_lag // test: External = Internal
test dum_w_ext_lag=dum_w_prop_lag // test: External = Proportional

*Fixed Effects
eststo: quietly: xi: areg transfers_pc `x' `controls_panel',  cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "N" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace
test dum_w_ext_lag=dum_w_int_lag // test: External = Internal
test dum_w_ext_lag=dum_w_prop_lag // test: External = Proportional

*Fixed Effects (time dummies)
eststo: quietly: xi: areg transfers_pc `x' `controls_panel' i.year , cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace
test dum_w_ext_lag==dum_w_int_lag // test: External = Internal
test dum_w_ext_lag=dum_w_prop_lag // test: External = Proportional

*Fixed Effects (region time dummies) 
eststo: quietly: xi: areg transfers_pc `x' `controls_panel'  i.year*i.region,  cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace
test dum_w_ext_lag=dum_w_int_lag // test: External = Internal
test dum_w_ext_lag=dum_w_prop_lag // test: External = Proportional


esttab  using ../../Tables/Table1.tex, replace  se(%3.2f) r2 keep(dum_w_ext_lag dum_w_int_lag dum_w_prop_lag) /*
*/ order(dum_w_ext_lag dum_w_int_lag dum_w_prop_lag pop_lag density_lag military capp surface) label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s(controls year_d region  year_region fixed r2 N, label("Controls" "Year effects" "Region effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("OLS" "Within-groups",pattern(1 1 0 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 


* (Table 3) Spending cycle *

gen first_year = 0
replace first_year = 1 if year == 1994 | year == 1996 |  year  == 2001 
gen last_year = 0
replace last_year = 1 if  year == 2000|  year  == 2005 

gen ext_first = 0 if dum_w_ext != .
gen ext_last = 0 if dum_w_ext != .

replace ext_last = last_year*dum_w_ext if dum_w_ext != .
replace ext_first = first_year*dum_w_ext if dum_w_ext != .

gen int_first = 0 if dum_w_int != .
gen int_last = 0 if dum_w_int != .

replace int_last = last_year*dum_w_int if dum_w_int != .
replace int_first = first_year*dum_w_int if dum_w_int != .

gen prop_first = 0 if dum_w_prop != .
gen prop_last = 0 if dum_w_prop != .

replace prop_last = last_year*dum_w_prop if dum_w_prop != .
replace prop_first = first_year*dum_w_prop if dum_w_prop != .

gen ext_first_lag = l.ext_first 
gen int_first_lag = l.int_first
gen prop_first_lag = l.prop_first

label var ext_first_lag "Ext.*first year"
label var int_first_lag "Int.*first year"
label var prop_first_lag "Prop.*first year"

gen ext_last_lag = l.ext_last 
gen int_last_lag = l.int_last
gen prop_last_lag = l.prop_last

label var ext_last_lag "Ext*last year"
label var int_last_lag "Int*last year"
label var prop_last_lag "Prop.*last year"


* Regressions *
eststo clear

eststo: quietly: xi: areg transfers_pc int_first_lag ext_first_lag  prop_first_lag dum_w_ext_lag dum_w_int_lag dum_w_prop_lag `controls_panel' /*
*/  i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc  int_last_lag ext_last_lag prop_last_lag  dum_w_ext_lag dum_w_int_lag dum_w_prop_lag `controls_panel' /*
*/  i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc  int_first_lag ext_first_lag  prop_first_lag  int_last_lag ext_last_lag prop_last_lag /*
*/  dum_w_ext_lag dum_w_int_lag dum_w_prop_lag `controls_panel' i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

esttab  using ../../Tables/Table_spending.tex , replace  se(%3.2f) r2 keep(int_first_lag ext_first_lag  prop_first_lag  int_last_lag ext_last_lag prop_last_lag /*
*/ dum_w_ext_lag dum_w_int_lag dum_w_prop_lag) label  star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s(controls year_d region  year_region fixed r2 N, label("Controls" "Year effects" "Region effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) 



* (Table 4) Localness (Marangoni/Tronconi dataset) *

preserve
* Preliminary: Save an auxiliary file with regional population variables for later *
use ../../Data/Other/Regions_population.dta, replace

drop if year == 2006
gen fraction = population/population_italy
label var fraction "Regional population / Italian population"

keep year region_code fraction
rename (region_code year)  (region_of_birth_code enter)


tempfile temp1 
save `temp1'

* Open MT's data and make it comparable to ours *
use ../../Data/Other/MPs_laws.dta, replace

rename leg legislature
keep if legislature >12 

egen id1 = group(name legislature)

tempfile MPs
save  `MPs', replace
 
use ../../Data/Data_Parliament.dta, replace
egen id2 = group(name legislature)

order leg name birth_town
sort leg name

drop if leg == 12 | house == 0
drop if birth_town == "FOREIGN"

reclink name leg  using `MPs', gen(myscore) idm(id2) idu(id1) required(legislature)
drop if myscore < 0.90  // Only one not found: Veltroni in the using dataset - we drop him *
drop myscore Uname Uleg _merge

* Some consistency issues with our dataset. Sometimes MT have a wrong birthtown and, hence, birth region.*
drop if (region_of_birth_code == region_of_election_code) & (regionor != regionel)
drop if constituency_bills == . & reg_or_bills != . // This is a mistake too, drop.
drop if constituency_bills != reg_or_bills & interior == 1 // This is a mistake too, drop.
drop if (constituency_bills > regional_bills  & reg_or_bills != . & constituency_bills != . & interior == 1  ) 

sort legislature name 
order name legislature ext interior locindex reg_or_bills regional

* Generate a variable for ext. elected OUTSIDE their region of birth *
gen ext_outside = (region_of_birth_code != region_of_election_code) & ext == 1

count if ext_outside == 1
count if exter == 1  // 38% of externals


* Table (generated by hand) *

* PANEL I- Bills *

* 1) All bills *
sum total_bills if interior == 1  & total_bills > 0
local n_t_int = r(mean)


sum total_bills if ext_outside == 1  & total_bills > 0
local n_t_ext = r(mean)

sum total_bills if prop == 1  & total_bills > 0
local n_t_prop = r(mean)


* 2) To all regions *
sum regional_bills if interior == 1  & total_bills > 0
local n_int = r(mean)

sum regional_bills if ext_outside == 1  & total_bills > 0 
local n_ext = r(mean)

sum regional_bills if prop == 1  & total_bills > 0
local n_prop = r(mean)


* 3) Of which (% of all regional bills): *

* To the region of election *
gen fraction_election = 100*constituency_bills/regional_bills 
* To the region of birth *
gen fraction_birth = 100*reg_or_bills/regional_bills 

order fract*

sum fraction_election if interior == 1  & total_bills > 0
local fraction_int = r(mean)

sum fraction_election if ext_outside == 1  & total_bills > 0 
local fraction_ext = r(mean)

sum fraction_election if prop == 1  & total_bills > 0
local fraction_prop = r(mean)

* To the region of birth *
sum fraction_birth if interior == 1  & total_bills > 0
local fraction_bint = r(mean)

sum fraction_birth if ext_outside == 1  & total_bills > 0 
local fraction_bext = r(mean)

sum fraction_birth if prop == 1  & total_bills > 0
local fraction_bprop = r(mean)


** Display Panel I ** 

disp  `n_t_int' "    " `n_t_ext' "       " `n_t_prop'  			    		// All bills
disp  `n_int' "    " `n_ext' "       " `n_prop'  							// Bills to all regions
disp  `fraction_int' "    " `fraction_ext' "      " `fraction_prop'		 	// Bills to region of election (%)
disp  `fraction_bint' "    " `fraction_bext' "      " `fraction_bprop' 		// Bills to region of birth (%)


* Extra - regressions *
keep if (interior == 1 | ext_outside == 1)& total_bills > 0

reg total_bills ext_outside if total_bills > 0
reg regional_bills ext_outside if total_bills > 0
reg fraction_election ext_outside if total_bills > 0
reg fraction_birth ext_outside if total_bills > 0

** PANEL II - Sample mean TESTING **

order fraction_* ext*  regional_bills reg_or constituency_bills region_of*

* 2.1) Is the fraction of bills sent to birth region unusually high? *
ttest fraction_birth == 5 if ext_outside == 1 // 20 regions, region of birth is only one so should receive 5% of all reg. bills

* 2.2) Is the fraction of bills sent to birth region unusually high? Use fraction
* of the Italian population that lives in the birth region as benchmark *

* First, Obtain data on regional population *
merge m:1 region_of_birth_code enter  using `temp1', assert(match) nogen
replace fraction = 100*fraction // To be comparable

* Generate a variable that is the difference between the fraction of regional bills
* sent to the birth region and the fraction of population that lives in the birth region *

gen fraction_birth_demean = fraction_birth - fraction
ttest fraction_birth_demean == 0 if ext_outside == 1

* In Panel II: p-values of the one-sided tests that the sample mean is larger than the 
* value chosen (5% in the first line, 0 in the second line).
 
restore


* (Table 5) District-level analysis *

preserve
set more off

* Idea: constituency either have an "internal" representative (captured by dum_w_int) or they have an "external" one (who may be born abroad too). For
* this reason, we can run a regression of transfers_pc at the constituency level on dum_w_cam_int (its maximum across all towns in the constituency, see
* the following collapse. The coefficient of dum_w_cam_int will give the extra transfers than a constituency receives if their representative is local.

for @ in any BARI BOLOGNA BRESCIA CAGLIARI CATANIA FIRENZE FOGGIA GENOVA LIVORNO MESSINA MILANO NAPOLI PADOVA PALERMO PRATO "REGGIO DI CALABRIA" ROMA SALERNO TORINO TRIESTE VENEZIA VERONA: drop if town=="@"
* Note: Trieste and Roma are already dropped. Only town w/o electoral area is Boville 1994. It's fine, because it was disbanded that year*
drop if electoral_area == ""  // Drop Boville 1994

collapse (sum) transfers  population surface (max) region_code dum_w_cam_int, by(year electoral_area)

gen density = population/surface
gen transfers_pc_const = transfers/(population)

* Drop foreign or zero transfers area (if they exist)
drop if transfers == 0 

egen id_c = group(electoral_area)
xtset id_c year

* Generating population polynomial (bands do not make sense anymore) *

gen pop2 = population^2
gen pop3 = population^3

* Define "ext" as those constituencies which are not represented by an int*

gen dum_w_cam_ext = dum_w_cam_int == 0 if dum_w_cam_int !=.

gen dum_w_cam_ext_lag = l.dum_w_cam_ext
label var dum_w_cam_ext_lag "Ext. connect"
label var transfers_pc_const "Transfers p.c."


eststo clear

eststo A: quietly: xi: reg transfers_pc_const dum_w_cam_ext_lag  l.density l.population l.pop2 l.pop3 i.year, cluster(id_c)
eststo B: quietly: xi: reg transfers_pc_const dum_w_cam_ext_lag  l.density l.population l.pop2 l.pop3 i.year i.region, cluster(id_c)
eststo C: quietly: xi: reg transfers_pc_const dum_w_cam_ext_lag  l.density l.population l.pop2 l.pop3  i.year*i.region, cluster(id_c)
eststo D: quietly: xi: areg transfers_pc_const dum_w_cam_ext_lag  l.density l.population l.pop2 l.pop3 i.year, cluster(id_c) absorb(id_c)

esttab A B C D using ../../Tables/Table_const.tex , replace  se(%3.2f) r2 keep(dum_w_cam_ext_lag) /*
*/ label   refcat(dum_w_cam_ext_lag "\vspace{0.2cm} \textbf{Panel A}: Camera", nolabel)   star(* 0.10 ** 0.05 *** 0.01)  f  nogaps noobs nonum booktabs collabels(none) /*
*/ s(r2 N, label( "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) 

restore
 

**** Senato *****

preserve
set more off

for @ in any BARI BOLOGNA BRESCIA CAGLIARI CATANIA FIRENZE FOGGIA GENOVA LIVORNO MESSINA MILANO NAPOLI PADOVA PALERMO PRATO "REGGIO DI CALABRIA" ROMA SALERNO TORINO TRIESTE VENEZIA VERONA: drop if town=="@"
* Note: Trieste and Roma are already dropped. Only town w/o electoral area is Boville 1994. It's fine, because it was disbanded that year *
drop if electoral_area == ""  // Drop Boville 1994

collapse (sum) transfers  population surface (max) region_code dum_w_sen_int, by(year electoral_area_s)

gen density = population/surface
gen transfers_pc_const = transfers/(population)

* Drop foreign or zero transfers area (if they exist)
drop if transfers == 0 

egen id_s = group(electoral_area_s)
xtset id_s year

* Generating population polynomial (bands do not make sense anymore) *
gen pop2 = population^2
gen pop3 = population^3

* Define "ext" as those constituencies which are not represented by an int*

gen dum_w_sen_ext = dum_w_sen_int == 0 if dum_w_sen_int !=.

gen dum_w_sen_ext_lag = l.dum_w_sen_ext
label var dum_w_sen_ext_lag "Ext. connect"
label var transfers_pc_const "Transfers p.c."

eststo E: quietly: xi: reg transfers_pc_const dum_w_sen_ext_lag  l.density l.population l.pop2 l.pop3 i.year, cluster(id_s)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "N" , replace

eststo F: quietly: xi: reg transfers_pc_const dum_w_sen_ext_lag  l.density l.population l.pop2 l.pop3 i.year i.region, cluster(id_s)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "N" , replace

eststo G: quietly: xi: reg transfers_pc_const dum_w_sen_ext_lag  l.density l.population l.pop2 l.pop3  i.year*i.region, cluster(id_s)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "N" , replace

eststo H: quietly: xi: areg transfers_pc dum_w_sen_ext_lag  l.density l.population l.pop2 l.pop3 i.year, cluster(id_s) absorb(id_s)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace


esttab E F G H  using ../../Tables/Table_const.tex, append  se(%3.2f) r2 keep( dum_w_sen_ext_lag) /*
*/ label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes refcat(dum_w_sen_ext_lag "\vspace{0.2cm} \textbf{Panel B}: Senato", nolabel) /*
*/ s( r2 N controls year_d region  year_region fixed , label("\emph{R}$^2$  " "Observations" "\hline Controls"  "Year effects" "Region effects" "Region-year effects"  "Constituency effects" )) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) noobs nonum nomtitles booktabs collabels(none)  

restore


*** (Table 6) Mechanisms ***

gen dum_w_ext_post_lag = l.dum_post_exp_any_ext  /* THIS is the usual one */
gen dum_w_int_post_lag = l.dum_post_exp_any_int
gen dum_w_prop_post_lag = l.dum_post_exp_any_prop

label var dum_w_ext_post_lag "Ext.*Posterior exp."
label var dum_w_int_post_lag "Int.*Posterior exp."
label var dum_w_prop_post_lag "Prop.*Posterior exp."

eststo clear

** Column 1 - Post-congressional career ***

local x "dum_w_ext_lag dum_w_ext_post_lag dum_w_int_lag dum_w_int_post_lag dum_w_prop_lag dum_w_prop_post_lag"

eststo: quietly: xi: areg transfers_pc `x' `controls_panel' i.year , cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace


** Column 2 - Party Alignment ***

local x "dum_w_ext_lag dum_w_int_lag dum_w_prop_lag dum_w_ext_align_party_lag dum_w_int_align_party_lag dum_w_prop_align_party_lag"   			

eststo: quietly: xi: areg transfers_pc  `x' `controls_panel'  i.year,  cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace


** Column 3 -  Mayor Alignment ***

local x "dum_w_ext_lag dum_w_int_lag dum_w_prop_lag dum_w_ext_align_surname_lag dum_w_int_align_surname_lag dum_w_prop_align_surname_lag"   			

eststo: quietly: xi: areg transfers_pc  `x' `controls_panel'  i.year,  cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace


** Column 4 -  All variables together ***

local x "dum_w_ext_lag dum_w_int_lag  dum_w_prop_lag dum_w_ext_post_lag dum_w_int_post_lag dum_w_prop_post_lag dum_w_ext_align_party_lag dum_w_int_align_party_lag dum_w_prop_align_party_lag dum_w_ext_align_surname_lag dum_w_int_align_surname_lag dum_w_prop_align_surname_lag "
eststo: quietly: xi: areg transfers_pc  `x' `controls_panel'  i.year,  cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace

esttab  using ../../Tables/Table_mech1.tex, replace  se(%3.2f) r2  keep(`x') order(`x') label star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes  /*
*/ s(controls year_d year_region fixed r2 N, label("Controls" "Year effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("Post-congress" "Aligned party" "Same surname" "All variables " ,pattern(1 1 1 1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 



* (Table 7) Placebos and robustness *

* A) Placebo *

gen ordinario_pc = ordinario/population
gen invest_svi_pc = invest_svi/population

label var ordinario_pc "Ordinary tr. p.c."
label var invest_svi_pc "Mortg. tr. p.c."

eststo clear

eststo: quietly: xi: areg transfers_pc dum_l_ext_lag dum_l_int_lag  `controls_panel'  i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc dum_r_all_lag  `controls_panel'   i.year*i.region , cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg invest_svi_pc dum_w_ext_lag dum_w_int_lag dum_w_prop_lag `controls_panel' i.year*i.region , cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg ordinario_pc dum_w_ext_lag dum_w_int_lag dum_w_prop_lag `controls_panel'  i.year*i.region , cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

esttab  using ../../Tables/Table_placebo.tex , replace  se(%3.2f) r2 keep(dum_l_ext_lag dum_l_int_lag dum_r_all_lag dum_w_ext_lag dum_w_int_lag dum_w_prop_lag) /*
*/ order(dum_l_ext_lag dum_l_int_lag dum_r_all_lag dum_w_ext_lag dum_w_int_lag dum_w_prop_lag ) label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s(controls year_d region  year_region fixed r2 N, label("Controls" "Year effects" "Region effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) 


* B) Robustness *

gen log_transfers_pc = 100*log(transfers_pc)
label var log_transfers_pc "Log transfers p.c."

eststo clear

* Logs *
eststo: quietly: xi: areg log_transfers_pc dum_w_ext_lag dum_w_int_lag dum_w_prop_lag `controls_panel'  i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

* Losers *
eststo: quietly: xi: areg transfers_pc dum_l_ext_lag dum_l_int_lag dum_r_all_lag dum_w_int_lag dum_w_ext_lag dum_w_prop_lag `controls_panel'  i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

* Commissions *
eststo: quietly: xi: areg transfers_pc dum_w_ext_lag dum_w_int_lag dum_w_prop_lag dum_w_ext_budg_lag dum_w_int_budg_lag dum_w_prop_budg_lag `controls_panel'  i.year*i.region, cluster(id) absorb(id)
estadd local controls "Y" , replace
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace

esttab  using ../../Tables/Table_robustness.tex , replace  se(%3.2f) r2 order(dum_l_ext_lag dum_l_int_lag dum_r_all_lag dum_w_ext_lag dum_w_int_lag dum_w_prop_lag dum_w_ext_budg_lag dum_w_int_budg_lag dum_w_prop_budg_lag) /*
*/ keep(dum_l_ext_lag dum_l_int_lag dum_r_all_lag dum_w_ext_lag dum_w_int_lag dum_w_prop_lag dum_w_ext_budg_lag dum_w_int_budg_lag dum_w_prop_budg_lag    ) /*
*/  label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s(controls year_d region  year_region fixed r2 N, label("Controls" "Year effects" "Region effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) 


