*******  Estimation - appendix tables ******** 

* Initialize*

clear all
set more off

use  ../../Data/Data_final.dta, replace

local controls "win_lag density_lag surface pop_lag military capp l1.pop2 l1.pop3 l1.pop_1 l1.pop_2 l1.pop_3 l1.pop_4 l1.pop_5 l1.pop_6 l1.pop_7 l1.pop_8 l1.pop_9 l1.pop_10 l1.pop_11 l1.pop_12 "  
local controls_panel "win_lag  density_lag pop_lag l1.pop2 l1.pop3 l1.pop_1 l1.pop_2 l1.pop_3 l1.pop_4 l1.pop_5 l1.pop_6 l1.pop_7 l1.pop_8 l1.pop_9 l1.pop_10 l1.pop_11 l1.pop_12 "

* A1) Counter *

local x "co_w_ext_lag co_w_int_lag co_w_prop_lag"   			

replace pop_lag = pop_lag/1000 // For interpretability of population coeff.

eststo clear

eststo: quietly: xi: reg transfers_pc `x' `controls' i.year i.region, cluster (id)
estadd local year_d "Y" , replace
estadd local region "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "N" , replace

eststo: quietly: xi: areg transfers_pc `x' `controls_panel',  cluster(id) absorb(id)
estadd local year_d "N" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc `x' `controls_panel' i.year , cluster(id) absorb(id)
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc `x' `controls_panel'  i.year*i.region, cluster(id) absorb(id)
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace


esttab  using ../../Tables/App_Table1.tex , replace  se(%3.2f) r2 keep(co_w_ext_lag co_w_int_lag co_w_prop_lag pop_lag military capp density_lag surface) /*
*/ order(co_w_ext_lag co_w_int_lag co_w_prop_lag pop_lag density_lag military capp surface) label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s( year_d region  year_region fixed r2 N, label("Year effects" "Region effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("OLS" "Within-groups",pattern(1 1 0 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 


* A2) Individual counter dummies *

* 1. Creating variables *

gen dum_1=(co_w_ext_lag==1) if year != 1994
gen dum_2to3=(co_w_ext_lag==2|co_w_ext_lag==3) if year != 1994
gen dum_g4=(co_w_ext_lag>=4 & co_w_ext_lag!=.) if year != 1994


label var dum_1 "Ext. connect1 t-1"
label var dum_2to3 "Ext. connect2_3 t-1"
label var dum_g4 "Ext. connect4 t-1"


* 2. Creating the actual table *

local x "dum_1 dum_2to3 dum_g4 dum_w_int_lag dum_w_prop_lag"   			

eststo clear

eststo: quietly: xi: reg transfers_pc `x' `controls' i.year i.region, cluster (id)
estadd local year_d "Y" , replace
estadd local region "Y" , replace
estadd local year_region "N" , replace
estadd local fixed "N" , replace

eststo: quietly: xi: areg transfers_pc `x' `controls_panel',  cluster(id) absorb(id)
estadd local year_d "N" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc `x' `controls_panel' i.year , cluster(id) absorb(id)
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "N" , replace
estadd local fixed "Y" , replace

eststo: quietly: xi: areg transfers_pc `x' `controls_panel'  i.year*i.region, cluster(id) absorb(id)
estadd local year_d "Y" , replace
estadd local region "N" , replace
estadd local year_region "Y" , replace
estadd local fixed "Y" , replace


esttab  using ../../Tables/App_Table2.tex , replace  se(%3.2f) r2 keep(dum_1 dum_2to3 dum_g4 dum_w_int_lag dum_w_prop_lag pop_lag military capp density_lag surface) /*
*/ order(dum_1 dum_2to3 dum_g4 dum_w_int_lag dum_w_prop_lag pop_lag density_lag military capp surface) label   star(* 0.10 ** 0.05 *** 0.01)  f nogaps  nonotes /*
*/ s( year_d region  year_region fixed r2 N, label("Year effects" "Region effects" "Region-year effects"  "Municipality effects" "\emph{R}$^2$  " "Observations")) /*
*/ alignment(c) sfmt(0) r2(0) b(a2) mgroups("OLS" "Within-groups",pattern(1 1 0 0)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 



